Learn R Programming

mztwinreg (version 1.0-1)

flu_weight: Flu, Body Weight and DNA methylation

Description

An artificial dataset containing information on flu, body weight and DNA methylation at an immune system gene locus, as well as demographic variables.

Usage

data("flu_weight")

Arguments

Format

A data frame with 200 observations on the following 7 variables.
DNAmeth
a numeric vector: DNA methylation fraction (ranging 0-1) at an immune system gene locus
FluNow
a numeric vector: Presence of severe flu at the moment of sample collection
FluChild
a numeric vector: History of recurrent flu during childhood
Gender
a character vector: Pair's gender
Age
a numeric vector: Pair's age
Weight
a numeric vector: Body weight in kilograms
PairNum
a numeric vector: Randomly assigned pair number

Details

As observed from this dataset, the individuals of the sample are sorted following two criteria: 1) twin pairs are put together (adjacent rows), and 2) all twins are discordant for present flu (FluNow).

The second condition is necessary only when using the log_dif function. It is recommended pre-sorting all datasets used along with this R package following criterion "1" or criteria "1" and "2".