data("flu_weight")DNAmethFluNowFluChildGenderAgeWeightPairNumFluNow). The second condition is necessary only when using the log_dif function.
It is recommended pre-sorting all datasets used along with this R package following criterion "1" or criteria "1" and "2".